@@ -23,9 +23,14 @@
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
+
+#if defined (HAVE_STDLIB_H)
+# include <stdlib.h>
+#elif defined (HAVE_MALLOC_H)
+# include <malloc.h>
 #endif
 
-#include <malloc.h>
+#endif
 
 /* If compiling with GCC, this file's not needed.  */
 #ifndef alloca
