@@ -179,21 +179,13 @@ main (int argc, char **argv)
   srand (time (0));
   setlocale (LC_ALL, "");
 
+  init_cmdline ();
+
   init_cmd_cdcd ();
   init_cmd_sites ();
   init_cmd_access ();
   init_cmd_edit ();
 
-  using_history ();
-
-  rl_readline_name = PACKAGE;
-  rl_completer_quote_characters = "\"'`";
-  rl_basic_word_break_characters = " ";
-
-  /* What is this for?  Seems to be unused, because it doesn't crash
-     even if we set it to NULL!  -- fb.  */
-  rl_basic_quote_characters = "\"'`";
-
   {
     struct cdcdrc conf;
     cdcdrc_read (&conf);
@@ -244,7 +236,7 @@ main (int argc, char **argv)
 	}
       else
 	{
-	  fputs ("cdcd: ", stderr);
+	  fputs ("cdcd: cannot initialize ", stderr);
 	  perror (device);
 	}
       exit (1);
