@@ -195,7 +195,9 @@ struct Command cmds[] = {
 };
 
 /* Concatenate the string array `S' into a space-separated newly
-   malloc'ed string.  */
+   malloc'ed string.
+
+   For example: {"hello","world","!"} -> "hello world !".  */
 /* To speed this up is possible but pointless */
 static char *
 concatnew (char **s)
