@@ -30,6 +30,11 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <stdlib.h>
 #include <errno.h>
 #include <stdio.h>
+#include <sys/ioctl.h>
+
+#ifdef HAVE_SYS_PTYVAR_H
+# include <sys/ptyvar.h>
+#endif
 
 #ifdef HAVE_STRING_H
 #include <string.h>
@@ -45,6 +50,20 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include "cdcd.h"
 #include "interface.h"
 
+void
+init_cmdline (void)
+{
+  using_history ();
+
+  rl_readline_name = PACKAGE;
+  rl_completer_quote_characters = "\"'`";
+  rl_basic_word_break_characters = " ";
+
+  /* What is this for?  Seems to be unused, because it doesn't crash
+     even if we set it to NULL!  -- fb.  */
+  rl_basic_quote_characters = "\"'`";
+}
+
 char *
 command_matcher (struct Command *c, const char *text, int state)
 {
@@ -66,12 +85,29 @@ command_matcher (struct Command *c, const char *text, int state)
   return NULL;
 }
 
-/* Returns the screen width (useful for prettyprintf's word break) */
+/* Returns the screen width (useful for prettyprintf's word
+   break).  */
 int
 get_width ()
 {
-  return 80;			/* It can vary (e.g. an xterm), but I don't know how to
-				   get that information yet. */
+  int cols = 0;
+  if (isatty (0))
+    {
+#ifdef TIOCGWINSZ
+      struct winsize size;
+
+      if (ioctl (0, TIOCGWINSZ, &size) != -1)
+	cols = size.ws_col;
+#else
+      struct ttysize size;
+
+      if (ioctl (input_fd, TIOCGSIZE, &size) != -1)
+	cols = size.ts_cols;
+#endif
+    }
+  if (cols == 0)
+    cols = 80;
+  return cols;
 }
 
 /* Read the string S; if it is in the form `[0-9]*:[0-9]*', set RET
@@ -304,7 +340,10 @@ find_command (char *name, struct Command *com)
 }
 
 /* Produce a malloc'ed string nicely representing an array of strings.
-   ARRAY is a NULL-terminated string array.  */
+   ARRAY is a NULL-terminated string array.
+
+   For example, with {"1","2","3","4"}: "1, 2, 3, and 4."
+*/
 /* FIXME: It's not a good idea to be so dependant of the language.
    Maybe we'll change this to a more universal representation of lists
    ("cmd  cmd  [...]  cmd").  */
@@ -320,13 +359,19 @@ array_to_string (const char *array[])
   for (i = 0; array[i]; ++i)
     {
       int comma, and, add;
+
+      /* Boolean variables: do we want a comma?  Do we want an
+	 "and"?  */
       comma = and = 0;
+
       if (i == 0)		/* the first one */
 	;
       else if (array[i + 1])	/* not the last one */
 	comma = 1;
       else			/* the last one */
 	and = 1;
+
+      /* Amount of text to add (and thus to allocate).  */
       add = (comma ? 2 : 0) + (and ? 6 : 0) + strlen (array[i]);
 
       if (len + add + 1 > capacity)
