@@ -55,6 +55,9 @@ struct Command
 
 #define ALIAS(from, to) { from, 0, 0, 0, to, 0 }
 
+/* Initialize the cmdline.c module.  */
+void init_cmdline (void);
+
 /* FIXME: this function is hell */
 void get_input_text (char *buffer, char *prompt, int len);
 char *trackname_matcher (const char *text, int state);
