@@ -29,7 +29,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef HAVE_STRING_H
 #include <string.h>
-#else
+#else if defined(HAVE_STRINGS_H)
 #include <strings.h>
 #endif
 
@@ -73,7 +73,6 @@ cdcdrc_data_mod (const char *var, const char *value, struct cdcdrc *conf)
 void
 cdcdrc_manual_configuration (struct cdcdrc *conf)
 {
-  void cdcdrc_write (const struct cdcdrc *);
   struct cddb_conf cddbconf;
   struct cddb_host proxy_host;
   struct cddb_serverlist list;
@@ -83,7 +82,7 @@ cdcdrc_manual_configuration (struct cdcdrc *conf)
 
   conf->verbosity = 1;
 
-  printf ("Welcome to %s %s.\n\n", PACKAGE, VERSION);
+  printf ("Welcome to %s %s.\n", PACKAGE, VERSION);
   pprintf (get_width () - 1,
 	   "You will now be asked a series of questions which will configure "
 	   "cdcd for your platform.  The default answers are given between "
