@@ -1,7 +1,7 @@
 /*
 cdcd - Command Driven CD player
 Copyright (C) 1998-99 Tony Arcieri
-Copyright (C) 2001 Fabrice BAUZAC
+Copyright (C) 2001, 2002, 2003 Fabrice Bauzac
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,15 +23,14 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include "cdcd.h"
 
-struct cdcdrc {
+struct cdcdrc
+{
   /* FIXME: use dynamically allocated strings.  */
   char device[CDCDRC_DEVICE_LEN];
   int verbosity;
 };
 
-int cdcdrc_data_mod (const char *var,
-		     const char *value,
-		     struct cdcdrc *conf);
+int cdcdrc_data_mod (const char *var, const char *value, struct cdcdrc *conf);
 void cdcdrc_manual_configuration (struct cdcdrc *conf);
 int cdcdrc_process_line (char *line, struct cdcdrc *conf);
 int cdcdrc_read (struct cdcdrc *conf);
