@@ -22,14 +22,24 @@
 
 /* NOTE!!!  AIX requires this to be the first thing in the file.
    Do not put ANYTHING before it!  */
+
 #if !defined (__GNUC__) && defined (_AIX)
 #pragma alloca
 #endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
+
+#if defined (HAVE_STRING_H)
+# include <string.h>
 #endif
 
+#if defined (HAVE_STRINGS_H)
+# include <strings.h>
+#endif
+
+#endif	/* HAVE_CONFIG_H */
+
 #ifdef __GNUC__
 #define alloca __builtin_alloca
 #else /* not __GNUC__ */
