@@ -1,7 +1,7 @@
 /*
 cdcd - Command Driven CD player
 Copyright (C) 1998-99 Tony Arcieri
-Copyright (C) 2001 Fabrice BAUZAC
+Copyright (C) 2001, 2002, 2003 Fabrice Bauzac
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,8 +23,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include "cdaudio.h"
 
-int cddb_get_siteslist (struct cddb_serverlist *list,
-			struct cddb_host host);
+int cddb_get_siteslist (struct cddb_serverlist *list, struct cddb_host host);
 int cdcd_cd_stat (int cd_desc, struct disc_info *disc);
 void cddb_lookup (int cd_desc, struct disc_data *data);
 void cddb_submit (int cd_desc, char *email_address);
