@@ -23,9 +23,11 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include "config.h"
 
-#ifdef HAVE_LIBCDAUDIO
+#if HAVE_LIBCDAUDIO
 #include <libcdaudio.h>
-#else
+#endif
+
+#if HAVE_CDAUDIO
 #include <cdaudio.h>
 #endif
 
