@@ -42,6 +42,13 @@ extern int vasprintf (char **, const char *, va_list);
 #include "cdcd.h"
 #include "str.h"
 
+#ifdef va_copy
+#elif defined (__va_copy)
+# define va_copy(va2, va) __va_copy ((va2), (va));
+#else
+# define va_copy(va2, va) memcpy (&(va2), &(va), sizeof (va));
+#endif
+
 /* Returns a malloc()ed string containing the lowercase version of S */
 char *
 strlowera (const char *s)
@@ -54,6 +61,8 @@ strlowera (const char *s)
   return r;
 }
 
+#if ! defined(HAVE_STRCASESTR)
+
 /* case-insensitive strstr() */
 const char *
 strcasestr (const char *u, const char *v)
@@ -78,6 +87,8 @@ strcasestr (const char *u, const char *v)
     }
 }
 
+#endif
+
 /* I don't know why, but these seem to not always work */
 
 #if 0
@@ -174,6 +185,42 @@ print_word (int width, char *w, struct pprintfd *ppd)
   ppd->liad = w[l - 1] == '.' ? 1 : 0;
 }
 
+#if ! HAVE_VASPRINTF
+# if HAVE_VSNPRINTF
+
+/* Replacement function for vasprintf, using vsnprintf.  */
+static void
+my_vasprintf (char **str, char *fmt, va_list va)
+{
+  /* Capacity (number of allocated bytes) of *STR.  */
+  size_t capacity = 1;
+
+  /* Number of chars (except final 0) to write to STR.  */
+  int total_len;
+
+  va_list va2;
+
+  *str = (char *) xmalloc (capacity);
+
+  va_copy (va2, va);
+
+  /* vsnprintf returns the strlen of the string that would be
+     generated (ie: we must allocate at least strlen+1 bytes).  */
+  total_len = vsnprintf (*str, capacity, fmt, va);
+  if (total_len >= capacity)
+    {
+      capacity = total_len + 1;
+      *str = (char *) xrealloc (*str, capacity);
+      vsnprintf (*str, capacity, fmt, va2);
+    }
+
+  va_end (va);
+  va_end (va2);
+}
+
+# endif	 /* HAVE_VSNPRINTF */
+#endif	 /* ! HAVE_VASPRINTF */
+
 /* These are the magic functions.  */
 
 /* vpdprintf does a printf() with word breaks; the width is MAXCOL.
@@ -187,7 +234,9 @@ vpdprintf (int maxcol, struct pprintfd *ppd, char *fmt, va_list v)
 
 #if HAVE_VASPRINTF
   vasprintf (&s, fmt, v);
-#else /* If we don't have vasprintf, we ought to have Glib.  */
+#elif HAVE_VSNPRINTF
+  my_vasprintf (&s, fmt, v);
+#elif HAVE_GLIB
   s = g_strdup_vprintf (fmt, v);
 #endif
 
