@@ -23,12 +23,15 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include <stdarg.h>
 
-/* TODO: We could explain how the functions work in .h's too.  */
+/* TODO: We could explain how the functions work in .h's too.  For
+   now, see str.c.  */
 
 int strnlower (char *dest, const char *src, int len);
 int strncasestr (const char *haystack, int haystacklen,
 		 const char *needle, int needlelen);
+#if ! defined(HAVE_STRCASESTR)
 const char *strcasestr (const char *haystack, const char *needle);
+#endif
 
 struct pprintfd
 {
@@ -47,7 +50,7 @@ struct pprintfd
 
   (*) If the cursor went to position 80, thus after having written 80
   characters on the line, the cursor would jump to the next line,
-  desyncronizing from pprintf's idea of the cursor position.
+  desynchronizing from pprintf's idea of the cursor position.
 
 */
 
